@@ -4,17 +4,18 @@
 #define SPRINGLOBBY_HEADERGUARD_AUIMANAGER_H
 
 #include <wx/aui/aui.h>
-
 class AuiManagerContainer
 {
-  public:
-    AuiManagerContainer() : manager(NULL) {}
+public:
+	AuiManagerContainer()
+	    : manager(NULL)
+	{
+	}
 
-    wxAuiManager* manager;
+	wxAuiManager* manager;
 };
 
 AuiManagerContainer& GetAui();
 
 
-
 #endif // SPRINGLOBBY_HEADERGUARD_AUIMANAGER_H
