@@ -84,7 +84,7 @@ bool CHttpDownloader::DownloadUrl(const std::string& url, std::string& res)
 	delete d.download;
 	d.download = nullptr;
 	if (curlres != CURLE_OK) {
-		LOG_ERROR("Error in curl %s", curl_easy_strerror(curlres));
+		LOG_ERROR("Error in curl %s (%s)", curl_easy_strerror(curlres), curlw.GetError().c_str());
 	}
 	return curlres == CURLE_OK;
 }
@@ -488,7 +488,7 @@ bool CHttpDownloader::processMessages(CURLM* curlm,
 							p.state = IDownload::STATE_NONE;
 							data->mirror->status = Mirror::STATUS_BROKEN;
 							// FIXME: cleanup curl handle here + process next dl
-							LOG_ERROR("Piece %d is invalid", idx);
+							LOG_WARN("Piece %d is invalid", idx);
 						}
 					} else {
 						LOG_INFO("sha1 checksum seems to be not set, can't check received "
@@ -542,12 +542,10 @@ static void CleanupDownloads(std::list<IDownload*>& download,
 	for (size_t i = 0; i < downloads.size(); i++) {
 		long timestamp = 0;
 		if ((downloads[i]->curlw != nullptr) &&
-		    curl_easy_getinfo(downloads[i]->curlw->GetHandle(), CURLINFO_FILETIME,
-				      &timestamp) == CURLE_OK) {
+		    curl_easy_getinfo(downloads[i]->curlw->GetHandle(), CURLINFO_FILETIME, &timestamp) == CURLE_OK) {
 			if (timestamp > 0) {
-				if (downloads[i]->download->state !=
-				    IDownload::STATE_FINISHED) // decrease local timestamp if download
-							       // failed to force redownload next time
+				// decrease local timestamp if download failed to force redownload next time
+				if (downloads[i]->download->state != IDownload::STATE_FINISHED)
 					timestamp--;
 				downloads[i]->download->file->SetTimestamp(timestamp);
 			}
