@@ -4,71 +4,70 @@
 #include "Download.h"
 #include "Http/HttpDownloader.h"
 #include "Rapid/RapidDownloader.h"
-//#include "Plasma/PlasmaDownloader.h"
+#include "CurlWrapper.h"
 #include "Util.h"
 #include "Logger.h"
 #include "Mirror.h"
-#include <curl/curl.h>
 
 class IDownloader;
 
-IDownloader* IDownloader::httpdl=NULL;
-//IDownloader* IDownloader::plasmadl=NULL;
-IDownloader* IDownloader::rapiddl=NULL;
+IDownloader* IDownloader::httpdl = NULL;
+IDownloader* IDownloader::rapiddl = NULL;
 IDownloaderProcessUpdateListener IDownloader::listener = nullptr;
 
-void IDownloader::Initialize(IDownloadsObserver* observer)
+
+
+
+void IDownloader::Initialize()
 {
-	curl_global_init(CURL_GLOBAL_ALL);
-	SetDownloadsObserver(observer);
+	CurlWrapper::InitCurl();
 }
 
 void IDownloader::Shutdown()
 {
-	delete(httpdl);
+	delete (httpdl);
 	httpdl = NULL;
-//	delete(plasmadl);
-//	plasmadl = NULL;
-	delete(rapiddl);
+	delete (rapiddl);
 	rapiddl = NULL;
-	curl_global_cleanup();
+	CurlWrapper::KillCurl();
+}
+static bool abortDownloads = false;
+void IDownloader::SetAbortDownloads(bool value)
+{
+	abortDownloads = value;
+}
+
+bool IDownloader::AbortDownloads()
+{
+	return abortDownloads;
 }
 
 IDownloader* IDownloader::GetHttpInstance()
 {
-	if (httpdl==NULL)
-		httpdl=new CHttpDownloader();
+	if (httpdl == NULL)
+		httpdl = new CHttpDownloader();
 	return httpdl;
 }
 IDownloader* IDownloader::GetRapidInstance()
 {
-	if (rapiddl==NULL)
-		rapiddl=new CRapidDownloader();
+	if (rapiddl == NULL)
+		rapiddl = new CRapidDownloader();
 	return rapiddl;
 }
-/*
-IDownloader* IDownloader::GetPlasmaInstance()
-{
-	if (plasmadl==NULL)
-		plasmadl=new CPlasmaDownloader();
-	return plasmadl;
-}
-*/
 
 bool IDownloader::download(std::list<IDownload*>& download, int max_parallel)
 {
-	std::list<IDownload*>::iterator it;
 	if (download.empty()) {
 		LOG_ERROR("download list empty");
 		return false;
 	}
-	bool res=true;
-	for (it=download.begin(); it!=download.end(); ++it) {
-		if (!(*it)->downloaded) //don't download twice
-			(*it)->downloaded=this->download(*it,max_parallel);
-		if (!(*it)->downloaded) {
-			res=false;
-		}
+	bool res = true;
+	for (IDownload* dl : download) {
+		if (dl->state == IDownload::STATE_FINISHED) // don't download twice
+			continue;
+
+		if (!this->download(dl, max_parallel))
+			res = false;
 	}
 	return res;
 }
@@ -77,13 +76,13 @@ bool IDownloader::download(IDownload* dl, int max_parallel)
 {
 	std::list<IDownload*> dls;
 	dls.push_back(dl);
-	return download(dls,max_parallel);
+	return download(dls, max_parallel);
 }
 
 void IDownloader::freeResult(std::list<IDownload*>& list)
 {
 	std::list<IDownload*>::iterator it;
-	for(it=list.begin(); it!=list.end(); ++it) {
+	for (it = list.begin(); it != list.end(); ++it) {
 		delete *it;
 	}
 	list.clear();
@@ -95,7 +94,7 @@ bool IDownloader::setOption(const std::string& key, const std::string& value)
 	return false;
 }
 
-void IDownloader::setProcessUpdateListener(IDownloaderProcessUpdateListener l) {
+void IDownloader::setProcessUpdateListener(IDownloaderProcessUpdateListener l)
+{
 	IDownloader::listener = l;
 }
-
