@@ -11,11 +11,9 @@ public:
 	Mirror(const std::string& url);
 	void UpdateSpeed(int speed);
 
-	enum MIRROR_STATUS {
-		STATUS_BROKEN,
-		STATUS_OK,
-		STATUS_UNKNOWN
-	} status;
+	enum MIRROR_STATUS { STATUS_BROKEN,
+			     STATUS_OK,
+			     STATUS_UNKNOWN } status;
 	std::string url;
 	int maxspeed;
 };
