@@ -23,7 +23,6 @@
 
 CRapidDownloader::CRapidDownloader()
     : url(REPO_MASTER)
-    , reposLoaded(false)
 {
 }
 
@@ -55,14 +54,6 @@ bool CRapidDownloader::list_compare(CSdp& first, CSdp& second)
 	return false;
 }
 
-bool CRapidDownloader::reloadRepos(const std::string& searchstr)
-{
-	if (reposLoaded)
-		return true;
-	reposLoaded = true;
-	return updateRepos(searchstr);
-}
-
 bool CRapidDownloader::download_name(IDownload* download, int reccounter,
 				     std::string name)
 {
@@ -102,7 +93,7 @@ bool CRapidDownloader::search(std::list<IDownload*>& result,
 			      DownloadEnum::Category cat)
 {
 	LOG_DEBUG("%s", name.c_str());
-	reloadRepos(name);
+	updateRepos(name);
 	sdps.sort(list_compare);
 	for (CSdp& sdp : sdps) {
 		if (match_download_name(sdp.getShortName(), name) ||
@@ -123,7 +114,7 @@ bool CRapidDownloader::download(IDownload* download, int /*max_parallel*/)
 		LOG_DEBUG("skipping non rapid-dl");
 		return true;
 	}
-	reloadRepos(download->origin_name);
+	updateRepos(download->origin_name);
 	return download_name(download, 0);
 }
 
@@ -157,11 +148,9 @@ bool CRapidDownloader::setOption(const std::string& key,
 {
 	if (key == "masterurl") {
 		url = value;
-		reposLoaded = false;
 		return true;
 	}
 	if (key == "forceupdate") {
-		reposLoaded = false;
 		return true;
 	}
 	return IDownloader::setOption(key, value);
@@ -179,8 +168,7 @@ void CRapidDownloader::downloadbyname(const std::string& name)
 	fileSystem->createSubdirs(CFileSystem::DirName(path));
 	LOG_DEBUG("%s", name.c_str());
 	// first try already downloaded file, as repo master file rarely changes
-	if ((fileSystem->fileExists(path)) &&
-	    (fileSystem->isOlder(path, REPO_MASTER_RECHECK_TIME)) && parse())
+	if ((fileSystem->fileExists(path)) && (!fileSystem->isOlder(path, REPO_MASTER_RECHECK_TIME)) && parse())
 		return;
 	IDownload dl(path);
 	dl.addMirror(name);
@@ -224,7 +212,6 @@ bool CRapidDownloader::parse()
 
 bool CRapidDownloader::updateRepos(const std::string& searchstr)
 {
-
 	std::string::size_type pos = searchstr.find(':');
 	std::string tag;
 	if (pos != std::string::npos) { // a tag is found, set it
