@@ -371,23 +371,33 @@ int CFileSystem::validatePool(const std::string& path, bool deletebroken)
 
 bool CFileSystem::isOlder(const std::string& filename, int secs)
 {
+	if (secs <= 0)
+		return true;
 	struct stat sb;
 	if (stat(filename.c_str(), &sb) < 0) {
 		return true;
 	}
-	time_t t;
 #ifdef WIN32
 	SYSTEMTIME pTime;
 	FILETIME pFTime;
 	GetSystemTime(&pTime);
 	SystemTimeToFileTime(&pTime, &pFTime);
-	t = FiletimeToTimestamp(pFTime);
-#else
-	time(&t);
-#endif
-	LOG_DEBUG("%s is %d seconds old, redownloading at %d", filename.c_str(),
-		  (int)(t - sb.st_ctime), secs);
+	const time_t t = FiletimeToTimestamp(pFTime);
+	LOG_DEBUG("%s is %d seconds old, redownloading at %d", filename.c_str(), (int)(t - sb.st_ctime), secs);
 	return (t < sb.st_ctime + secs);
+
+#else
+	time_t t;
+	time(&t);
+	struct tm lt;
+	localtime_r(&sb.st_mtime, &lt);
+
+	const time_t filetime = mktime(&lt);
+	const double diff = difftime(t, filetime);
+
+	LOG_DEBUG("checking time: %s  %.0fs >  %ds res: %d", filename.c_str(), diff, secs, (bool)(diff > secs));
+	return (diff > secs);
+#endif
 }
 
 bool CFileSystem::fileExists(const std::string& path)
