@@ -1,42 +1,34 @@
 /*
-	header for pr-downloader
+        header for pr-downloader
 */
 
-
 #ifndef PR_DOWNLOADER_H
 #define PR_DOWNLOADER_H
 
-enum category {
-	CAT_MAP,
-	CAT_GAME,
-	CAT_ENGINE,
-	CAT_ANY
-};
-
-enum downloadtype {
-	DL_RAPID,
-	DL_HTTP,
-//	DL_PLASMA,
-	DL_ENGINE, //FIXME: also in category
-	DL_ANY
-};
+#include "Downloader/DownloadEnum.h"
 
 #define NAME_LEN 1024
-struct downloadInfo {
+struct downloadInfo
+{
 	char filename[NAME_LEN];
 	bool validated;
 	int speed;
-	downloadtype type;
-	category cat;
+	DownloadEnum::Category cat;
 };
 /**
-	downloads all downloads that where added with @DownloadAdd
-	clears search results
+        downloads all downloads that where added with @DownloadAdd
+        clears search results
 */
 extern int DownloadStart();
 
 /**
-	adds a download, see @DownloadSearch & @DownloadGetSearchInfo
+        adds a download by url without searching
+*/
+extern int DownloadAddByUrl(DownloadEnum::Category cat, const char* filename,
+			    const char* url);
+
+/**
+        adds a download, see @DownloadSearch & @DownloadGetSearchInfo
 */
 extern bool DownloadAdd(unsigned int id);
 /**
@@ -45,12 +37,12 @@ extern bool DownloadAdd(unsigned int id);
 * @return count of results
 * @see downloadSearchGetId
 */
-extern int DownloadSearch(downloadtype type, category cat, const char* name);
+extern int DownloadSearch(DownloadEnum::Category category, const char* name);
 
 /**
-*	get info about a search result
+*	get info about a result / current download
 */
-extern bool DownloadGetSearchInfo(int id, downloadInfo& info);
+extern bool DownloadGetInfo(int id, downloadInfo& info);
 
 /**
 *	Initialize the lib
@@ -62,8 +54,9 @@ extern void DownloadInit();
 extern void DownloadShutdown();
 
 enum CONFIG {
-	CONFIG_FILESYSTEM_WRITEPATH = 1, //const char, sets the output directory
-	CONFIG_FETCH_DEPENDS //bool, automaticly fetch depending files
+	CONFIG_FILESYSTEM_WRITEPATH = 1, // const char, sets the output directory
+	CONFIG_FETCH_DEPENDS,		 // bool, automaticly fetch depending files
+	CONFIG_RAPID_FORCEUPDATE,	// bool, always fetch repo files
 };
 
 /**
@@ -87,6 +80,11 @@ extern bool DownloadRapidValidate(bool deletebroken);
 */
 extern bool DownloadDumpSDP(const char* path);
 
+/**
+* validate sdp files
+*/
+extern bool ValidateSDP(const char* path);
+
 /**
 * control printing to stdout
 */
@@ -95,5 +93,18 @@ extern void DownloadDisableLogging(bool disableLogging);
 typedef void (*IDownloaderProcessUpdateListener)(int done, int size);
 
 extern void SetDownloadListener(IDownloaderProcessUpdateListener listener);
-#endif
 
+/*
+ * Calculate hash and return it in base64 format.
+ * Accepted values for type are:
+ *   0 - md5
+*/
+extern char* CalcHash(const char* str, int size, int type);
+
+/**
+* abort all downloads - must be called before shutting down,
+* all downloads must return before calling shutdown
+*/
+extern void SetAbortDownloads(bool value);
+
+#endif
