@@ -17,7 +17,7 @@ slAboutBox::slAboutBox()
 	info->SetVersion(TowxString(GetSpringlobbyVersion()));
 	info->SetDescription(TowxString(GetSpringlobbyName()) + _(" is a cross-platform lobby client for the Spring RTS engine"));
 	//info.SetCopyright(wxEmptyString;
-	info->SetWebSite(_T("https://springlobby.info"));
+	info->SetWebSite(_T("https://springlobby.springrts.com"));
 	info->SetLicence(_T("GPL v2 or later"));
 	info->AddDeveloper(_T("abma"));
 	info->AddDeveloper(_T("BrainDamage"));
