@@ -28,6 +28,7 @@ public:
 	void OnLoginDenied(const wxString& reason);
 	void OnRegistrationAccepted(const wxString& user, const wxString& pass);
 	void OnRegistrationDenied(const wxString& reason);
+
 private:
 	void OnCancel(wxCommandEvent& event);
 	void OnOk(wxCommandEvent& event);
@@ -73,6 +74,8 @@ private:
 	wxTextCtrl* m_regpass1_text;
 	wxStaticText* m_regpass2_lbl;
 	wxTextCtrl* m_regpass2_text;
+	wxStaticText* m_regemail_lbl;
+	wxTextCtrl* m_regemail_text;
 	wxStaticText* m_reginfo_text;
 
 	Ui& m_ui;
