@@ -1,31 +1,30 @@
 /* This file is part of the Springlobby (GPL v2 or later), see COPYING */
-
 #include "contentdownloaddialog.h"
-#include "contentsearchresultview.h"
-#include "utils/conversion.h"
-
-#include <wx/sizer.h>
-#include <wx/textctrl.h>
-#include <wx/stattext.h>
-#include <wx/button.h>
-#include <wx/msgdlg.h>
-
-#include "downloader/lib/src/Downloader/Http/HttpDownloader.h"
-
-#include "httpfile.h"
-#include "ui.h"
-#include "servermanager.h"
 
 #include <lslunitsync/unitsync.h>
+#include <wx/button.h>
+#include <wx/msgdlg.h>
+#include <wx/sizer.h>
+#include <wx/stattext.h>
+#include <wx/textctrl.h>
+
+#include "contentsearchresultview.h"
+#include "downloader/lib/src/Downloader/Http/HttpDownloader.h" //FIXME: remove this
+#include "downloader/prdownloader.h"
+#include "httpfile.h"
+#include "servermanager.h"
+#include "ui.h"
+#include "utils/conversion.h"
+#include "utils/slpaths.h"
 
 DECLARE_EVENT_TYPE(SEARCH_FINISHED, wxID_ANY);
 DEFINE_EVENT_TYPE(SEARCH_FINISHED);
 BEGIN_EVENT_TABLE(ContentDownloadDialog, wxDialog)
-	EVT_BUTTON(SEARCH_BUTTON, ContentDownloadDialog::OnSearch)
-	EVT_BUTTON(CLOSE_BUTTON, ContentDownloadDialog::OnCloseButton)
-	EVT_BUTTON(DOWNLOAD_BUTTON, ContentDownloadDialog::OnDownloadButton)
-	EVT_COMMAND(ID_SEARCH_FINISHED, SEARCH_FINISHED, ContentDownloadDialog::OnSearchCompleted)
-	EVT_DATAVIEW_ITEM_ACTIVATED(LAUNCH_DOWNLOAD, ContentDownloadDialog::OnListDownload)
+EVT_BUTTON(SEARCH_BUTTON, ContentDownloadDialog::OnSearch)
+EVT_BUTTON(CLOSE_BUTTON, ContentDownloadDialog::OnCloseButton)
+EVT_BUTTON(DOWNLOAD_BUTTON, ContentDownloadDialog::OnDownloadButton)
+EVT_COMMAND(ID_SEARCH_FINISHED, SEARCH_FINISHED, ContentDownloadDialog::OnSearchCompleted)
+EVT_DATAVIEW_ITEM_ACTIVATED(LAUNCH_DOWNLOAD, ContentDownloadDialog::OnListDownload)
 END_EVENT_TABLE()
 
 ContentDownloadDialog::ContentDownloadDialog(wxWindow* parent, wxWindowID id, const wxString& title, const wxPoint& pos, const wxSize& size, long int style, const wxString& name)
@@ -83,7 +82,7 @@ void ContentDownloadDialog::Search(const wxString& str)
 {
 	//FIXME: make async!
 	const std::string param = ConvToIRI(STD_STRING(str));
-	const std::string query = stdprintf("http://api.springfiles.com/json.php?nosensitive=on&logical=or&springname=%s&tag=%s", param.c_str(), param.c_str());
+	const std::string query = stdprintf("https://api.springfiles.com/json.php?nosensitive=on&logical=or&springname=%s&tag=%s", param.c_str(), param.c_str());
 	std::string res;
 	CHttpDownloader::DownloadUrl(query, res);
 	CHttpDownloader::ParseResult(STD_STRING(str), res, dls);
@@ -109,18 +108,29 @@ void ContentDownloadDialog::OnSearchCompleted(wxCommandEvent& /*event*/)
 	wildcardsearch = false;
 	m_search_res_w->Clear();
 
-	for (const IDownload* dl:dls) {
+	for (const IDownload* dl : dls) {
 		ContentSearchResult* res = new ContentSearchResult();
 		res->name = dl->origin_name;
 		res->filesize = dl->size;
-		res->type = dl->getCat(dl->cat);
-		if (res->type == "map")
-			res->is_downloaded = LSL::usync().MapExists(dl->name);
-		else if (res->type == "game")
-			res->is_downloaded = LSL::usync().GameExists(dl->name);
-		else
-			res->is_downloaded = false;
-
+		res->type = DownloadEnum::getCat(dl->cat);
+		res->category = dl->cat;
+		switch (dl->cat) {
+			case DownloadEnum::CAT_MAP:
+				res->is_downloaded = LSL::usync().MapExists(dl->origin_name);
+				break;
+			case DownloadEnum::CAT_GAME:
+				res->is_downloaded = LSL::usync().GameExists(dl->origin_name);
+				break;
+			case DownloadEnum::CAT_ENGINE: //FIXME: check if platform matches / filter out different platform (?)
+			case DownloadEnum::CAT_ENGINE_LINUX:
+			case DownloadEnum::CAT_ENGINE_LINUX64:
+			case DownloadEnum::CAT_ENGINE_MACOSX:
+			case DownloadEnum::CAT_ENGINE_WINDOWS:
+				res->is_downloaded = !SlPaths::GetCompatibleVersion(dl->version).empty();
+				break;
+			default:
+				res->is_downloaded = false;
+		}
 		m_search_res_w->AddContent(*res);
 	}
 	IDownloader::freeResult(dls);
@@ -144,6 +154,5 @@ void ContentDownloadDialog::OnListDownload(wxDataViewEvent& /*event*/)
 	if (res == nullptr) {
 		return;
 	}
-
-	ServerManager::Instance()->DownloadContent(STD_STRING(res->type), STD_STRING(res->name), "");
+	prDownloader().Download(res->category, STD_STRING(res->name));
 }
