@@ -1,35 +1,35 @@
 
-#include <wx/sizer.h>
-#include <wx/statbox.h>
-#include <wx/checkbox.h>
-#include <wx/slider.h>
-#include <wx/combobox.h>
-#include <wx/stattext.h>
-#include <wx/choicdlg.h>
-#include <wx/defs.h>
-#include <wx/intl.h>
-#include <wx/button.h>
-#include <wx/tipwin.h>
-#include <wx/tooltip.h>
-#include <wx/textctrl.h>
-#include <wx/spinctrl.h>
-#include <map>
-
-#include "gui/controls.h"
-#include "utils/conversion.h"
-#include "battle.h"
-#include "gui/customdialogs.h"
-#include "iserver.h"
-#include "settings.h"
-#include "gui/ui.h"
-#include "aui/auimanager.h"
 #include "battleroommmoptionstab.h"
-#include "utils/lslconversion.h"
 
-#include <lslutils/misc.h>
-#include <lslutils/conversion.h>
 #include <lslunitsync/optionswrapper.h>
 #include <lslunitsync/unitsync.h>
+#include <lslutils/conversion.h>
+#include <lslutils/misc.h>
+#include <wx/button.h>
+#include <wx/checkbox.h>
+#include <wx/choicdlg.h>
+#include <wx/combobox.h>
+#include <wx/defs.h>
+#include <wx/intl.h>
+#include <wx/sizer.h>
+#include <wx/slider.h>
+#include <wx/spinctrl.h>
+#include <wx/statbox.h>
+#include <wx/stattext.h>
+#include <wx/textctrl.h>
+#include <wx/tipwin.h>
+#include <wx/tooltip.h>
+#include <map>
+
+#include "aui/auimanager.h"
+#include "battle.h"
+#include "gui/controls.h"
+#include "gui/customdialogs.h"
+#include "gui/ui.h"
+#include "iserver.h"
+#include "settings.h"
+#include "utils/conversion.h"
+#include "utils/lslconversion.h"
 
 const char sep = '_';
 const wxString wxsep = _T("_");
@@ -462,7 +462,7 @@ void BattleroomMMOptionsTab::OnReloadControls(const LSL::Enum::GameOption& flag)
 	//this->SetSizer( m_main_sizer, true );
 	m_main_sizer->FitInside(this);
 
-	this->Layout();
+	Layout();
 	SetScrollbars(10, 10, 62, 62);
 }
 
@@ -480,7 +480,7 @@ void BattleroomMMOptionsTab::OnLoadPreset(wxCommandEvent& /*unused*/)
 		return;
 	std::string presetname = STD_STRING(m_options_preset_sel->GetValue());
 	if (presetname.empty()) {
-		customMessageBoxNoModal(SL_MAIN_ICON, _("Cannot load an options set without a name\nPlease select one from the list and try again."), _("error"), wxICON_EXCLAMATION | wxOK);
+		customMessageBoxModal(SL_MAIN_ICON, _("Cannot load an options set without a name\nPlease select one from the list and try again."), _("error"), wxICON_EXCLAMATION | wxOK);
 		return;
 	}
 	m_battle->LoadOptionsPreset(presetname);
@@ -497,7 +497,7 @@ void BattleroomMMOptionsTab::OnSavePreset(wxCommandEvent& /*unused*/)
 	if (!ui().AskText(_("Enter preset name"), _("Enter a name to save the current set of options\nIf a preset with the same name already exist, it will be overwritten"), presetname))
 		return;
 	if (presetname.empty()) {
-		customMessageBoxNoModal(SL_MAIN_ICON, _("Cannot save an options set without a name."), _("error"), wxICON_EXCLAMATION | wxOK);
+		customMessageBoxModal(SL_MAIN_ICON, _("Cannot save an options set without a name."), _("error"), wxICON_EXCLAMATION | wxOK);
 		return;
 	}
 	m_battle->SaveOptionsPreset(STD_STRING(presetname));
