@@ -3,33 +3,31 @@
 //
 // Class: MainJoinBattleTab
 //
+#include "mainjoinbattletab.h"
 
 #include <wx/icon.h>
-#include <wx/intl.h>
-#include <wx/notebook.h>
 #include <wx/imaglist.h>
+#include <wx/intl.h>
+#include <wx/log.h>
+#include <wx/notebook.h>
 #include <wx/sizer.h>
 #include <wx/wupdlock.h>
-#include <wx/log.h>
+#include <stdexcept>
 
-#include "settings.h"
-#include "mainjoinbattletab.h"
-#include "battleroomtab.h"
-#include "battlemaptab.h"
-#include "battleoptionstab.h"
-#include "utils/conversion.h"
-#include "battleroommmoptionstab.h"
 #include "aui/auimanager.h"
-#include "gui/slbook.h"
+#include "battlemaptab.h"
+#include "battlerestrictionstab.h"
+#include "battleroommmoptionstab.h"
+#include "battleroomtab.h"
 #include "gui/controls.h"
-#include "log.h"
-
-#include "images/battle_list.xpm"
+#include "gui/slbook.h"
 #include "images/battle.xpm"
+#include "images/battle_list.xpm"
 #include "images/battle_map.xpm"
 #include "images/battle_settings.xpm"
-
-#include <stdexcept>
+#include "log.h"
+#include "settings.h"
+#include "utils/conversion.h"
 
 MainJoinBattleTab::MainJoinBattleTab(wxWindow* parent)
     : wxPanel(parent, -1)
@@ -60,7 +58,7 @@ MainJoinBattleTab::MainJoinBattleTab(wxWindow* parent)
 	m_mm_opts_tab = new BattleroomMMOptionsTab(0, m_tabs);
 	m_tabs->InsertPage(2, m_mm_opts_tab, _("Options"), false, wxIcon(battle_settings_xpm));
 
-	m_opts_tab = new BattleOptionsTab(m_tabs, 0);
+	m_opts_tab = new BattleRestrictionsTab(m_tabs, 0);
 	m_tabs->InsertPage(3, m_opts_tab, _("Unit Restrictions"), false, wxIcon(battle_settings_xpm));
 
 	m_main_sizer->Add(m_tabs, 1, wxEXPAND);
@@ -89,17 +87,11 @@ ChatPanel* MainJoinBattleTab::GetActiveChatPanel()
 	return NULL;
 }
 
-void MainJoinBattleTab::UpdateCurrentBattle()
-{
-	GetBattleRoomTab().UpdateBattleInfo();
-	GetBattleMapTab().Update();
-}
-
 void MainJoinBattleTab::UpdateCurrentBattle(const wxString& Tag)
 {
 	GetBattleRoomTab().UpdateBattleInfo(Tag);
 	GetBattleMapTab().Update(Tag);
-	GetOptionsTab().UpdateBattle(Tag);
+	GetOptionsTab().ReloadRestrictions();
 	GetMMOptionsTab().UpdateOptControls(Tag);
 }
 
@@ -166,7 +158,7 @@ BattleMapTab& MainJoinBattleTab::GetBattleMapTab()
 }
 
 
-BattleOptionsTab& MainJoinBattleTab::GetOptionsTab()
+BattleRestrictionsTab& MainJoinBattleTab::GetOptionsTab()
 {
 	ASSERT_EXCEPTION(m_opts_tab, _T( "m_opts_tab == 0" ));
 	return *m_opts_tab;
