@@ -1,27 +1,24 @@
 /* This file is part of the Springlobby (GPL v2 or later), see COPYING */
+#include "gui/hosting/mainsingleplayertab.h"
 
-#include <wx/intl.h>
-#include <wx/window.h>
-#include <wx/sizer.h>
-#include <wx/imaglist.h>
 #include <wx/icon.h>
+#include <wx/imaglist.h>
+#include <wx/intl.h>
 #include <wx/log.h>
-
+#include <wx/sizer.h>
+#include <wx/window.h>
 #include <stdexcept>
 
 #include "aui/auimanager.h"
-#include "gui/slbook.h"
-#include "gui/singleplayertab.h"
-#include "gui/hosting/battleoptionstab.h"
-#include "gui/hosting/mainsingleplayertab.h"
-#include "gui/hosting/battleroommmoptionstab.h"
-#include "utils/conversion.h"
 #include "gui/controls.h"
-#include "log.h"
-
+#include "gui/hosting/battlerestrictionstab.h"
+#include "gui/hosting/battleroommmoptionstab.h"
+#include "gui/singleplayertab.h"
+#include "gui/slbook.h"
 #include "images/battle.xpm"
 #include "images/battle_settings.xpm"
-
+#include "log.h"
+#include "utils/conversion.h"
 
 MainSinglePlayerTab::MainSinglePlayerTab(wxWindow* parent)
     : wxPanel(parent, -1)
@@ -39,7 +36,7 @@ MainSinglePlayerTab::MainSinglePlayerTab(wxWindow* parent)
 	m_tabs->AddPage(m_sp_tab, _("Game"), true, wxNullBitmap);
 	m_mm_opts_tab = new BattleroomMMOptionsTab(&m_sp_tab->GetBattle(), m_tabs);
 	m_tabs->InsertPage(1, m_mm_opts_tab, _("Options"), false, wxIcon(battle_settings_xpm));
-	m_opts_tab = new BattleOptionsTab(m_tabs, &m_sp_tab->GetBattle());
+	m_opts_tab = new BattleRestrictionsTab(m_tabs, &m_sp_tab->GetBattle());
 	m_tabs->InsertPage(2, m_opts_tab, _("Unit Restrictions"), false, wxIcon(battle_settings_xpm));
 
 	m_main_sizer->Add(m_tabs, 1, wxEXPAND);
@@ -51,6 +48,7 @@ MainSinglePlayerTab::MainSinglePlayerTab(wxWindow* parent)
 
 MainSinglePlayerTab::~MainSinglePlayerTab()
 {
+	wxDELETE(m_imagelist);
 	//    if ( sett().GetAutosavePerspective() )
 	//        SavePerspective();
 }
@@ -122,7 +120,7 @@ SinglePlayerTab& MainSinglePlayerTab::GetSinglePlayerTab()
 	return *m_sp_tab;
 }
 
-BattleOptionsTab& MainSinglePlayerTab::GetOptionsTab()
+BattleRestrictionsTab& MainSinglePlayerTab::GetOptionsTab()
 {
 	ASSERT_EXCEPTION(m_opts_tab, _T( "m_opts_tab == 0" ));
 	return *m_opts_tab;
