@@ -443,6 +443,8 @@ void MainWindow::OpenChannelChat(Channel& channel, bool doFocus)
 //! @param nick The user to whom the chatwindow should be opened to
 void MainWindow::OpenPrivateChat(User& user, bool doFocus)
 {
+	if (user.IsBridged())
+		return;
 	ASSERT_LOGIC(m_chat_tab != 0, "m_chat_tab");
 	m_func_tabs->SetSelection(PAGE_CHAT);
 	ChatPanel* cp = m_chat_tab->AddChatPanel(user);
@@ -668,8 +670,7 @@ void MainWindow::OnMenuResetLayout(wxCommandEvent& /*event*/)
 {
 	cfg().Write(_T( "/ResetLayout" ), true);
 	sett().SaveSettings();
-	customMessageBoxModal(SL_MAIN_ICON, wxString::Format(
-	  _("Please restart %s now"), GetSpringlobbyName()), wxEmptyString);
+	customMessageBoxModal(SL_MAIN_ICON, wxString::Format(_("Please restart %s now"), GetSpringlobbyName()), wxEmptyString);
 }
 
 const wxArrayString& MainWindow::GetTabNames()
