@@ -3,10 +3,9 @@
 #ifndef SPRINGLOBBY_HEADERGUARD_MAINWINDOW_H
 #define SPRINGLOBBY_HEADERGUARD_MAINWINDOW_H
 
-#include <wx/intl.h>
 #include <wx/frame.h>
+#include <wx/intl.h>
 #include "gui/windowattributespickle.h"
-
 class Ui;
 class Channel;
 class User;
@@ -41,7 +40,7 @@ class OptionsDialog;
 class ReplayTraits;
 class wxFocusEvent;
 
-static const wxEventType MainwindowMessageEvent = wxNewEventType();
+extern const wxEventType MainwindowMessageEvent;
 
 //! @brief wxFrame that contains the main window of the client.
 class MainWindow : public wxFrame, public WindowAttributesPickle
@@ -84,7 +83,6 @@ public:
 	void OnShowChannelChooser(wxCommandEvent& event);
 	void OnShowWriteableDir(wxCommandEvent& event);
 	void forceSettingsFrameClose();
-	void OnUnitSyncReloaded();
 	void OnChannelList(const wxString& channel, const int& numusers, const wxString& topic);
 	void OnChannelListStart();
 	void OnClose(wxCloseEvent&);
@@ -114,7 +112,7 @@ public:
 	void SavePerspectives(const wxString& perspective_name = wxEmptyString);
 
 private:
-	void OnGamePromoted(wxCommandEvent&);
+	void OnUnitSyncReloaded(wxCommandEvent& /*unused*/);
 
 private:
 	wxMenuItem* m_settings_menu;
@@ -185,12 +183,12 @@ private:
 public:
 	// Page indexes
 	static const unsigned int PAGE_CHAT = 0;
-	static const unsigned int PAGE_LIST = 1;
-	static const unsigned int PAGE_JOIN = 2;
-	static const unsigned int PAGE_SINGLE = 3;
-	static const unsigned int PAGE_REPLAY = 4;
+	static const unsigned int PAGE_BATTLELIST = 1;
+	static const unsigned int PAGE_BATTLEROOM = 2;
+	static const unsigned int PAGE_SINGLEPLAYER = 3;
+	static const unsigned int PAGE_REPLAYS = 4;
 	//        static const unsigned int PAGE_SAVEGAME = 4;
-	static const unsigned int PAGE_TORRENT = 5;
+	static const unsigned int PAGE_DOWNLOADS = 5;
 
 	static const unsigned int OPT_PAGE_SPRING = 0;
 	static const unsigned int OPT_PAGE_CHAT = 1;
