@@ -1,52 +1,45 @@
 /* This file is part of the Springlobby (GPL v2 or later), see COPYING */
-
-#include <wx/panel.h>
-#include <wx/dcclient.h>
-#include <wx/bitmap.h>
-#include <wx/image.h>
-#include <wx/intl.h>
-#include <cmath>
-#include <stdexcept>
-#include <wx/log.h>
-#include <wx/app.h>
-#include <wx/toplevel.h>
-
 #define HAVE_WX
+#include "mapctrl.h"
+
+#include <lslunitsync/data.h>
+#include <lslunitsync/image.h>
 #include <lslutils/conversion.h>
 #include <lslutils/misc.h>
-#include <lslunitsync/image.h>
-#include <lslunitsync/data.h>
+#include <wx/app.h>
+#include <wx/bitmap.h>
+#include <wx/dcclient.h>
+#include <wx/image.h>
+#include <wx/intl.h>
+#include <wx/log.h>
+#include <wx/panel.h>
+#include <wx/toplevel.h>
+#include <cmath>
+#include <functional>
+#include <stdexcept>
 
-#include "utils/conversion.h"
-#include "uiutils.h"
-#include "mapctrl.h"
-#include "user.h"
-#include "ui.h"
-#include "iserver.h"
-#include "ibattle.h"
-#include "settings.h"
-#include "iconimagelist.h"
-#include "hosting/addbotdialog.h"
-#include "log.h"
-#include "contentmanager.h"
-#include "contentdownloadrequest.h"
 #include "exception.h"
-
+#include "hosting/addbotdialog.h"
+#include "ibattle.h"
+#include "iconscollection.h"
 #include "images/close.xpm"
 #include "images/close_hi.xpm"
+#include "images/download_map.xpm"
+#include "images/not_found_icon.xpm"
+#include "images/reload_map.xpm"
 #include "images/start_ally.xpm"
 #include "images/start_enemy.xpm"
 #include "images/start_unused.xpm"
-#include "images/player.xpm"
-#include "images/bot.xpm"
-#include "images/no1_icon.png.h"
-#include "images/no2_icon.png.h"
 #include "images/up_down.xpm"
-#include "images/upsel_down.xpm"
 #include "images/up_downsel.xpm"
-#include "images/not_found_icon.xpm"
-#include "images/download_map.xpm"
-#include "images/reload_map.xpm"
+#include "images/upsel_down.xpm"
+#include "iserver.h"
+#include "log.h"
+#include "settings.h"
+#include "ui.h"
+#include "uiutils.h"
+#include "user.h"
+#include "utils/conversion.h"
 #include "utils/lslconversion.h"
 
 const int USER_BOX_EXPANDED_HEIGHT = 70;
@@ -107,7 +100,7 @@ static inline int ReadInt24(const unsigned char* p)
 
 MapCtrl::MapCtrl(wxWindow* parent, int size, IBattle* battle, bool readonly, bool draw_start_types, bool singleplayer)
     : wxPanel(parent, -1, wxDefaultPosition, wxSize(size, size), wxSIMPLE_BORDER | wxFULL_REPAINT_ON_RESIZE)
-    , m_async(boost::bind(&MapCtrl::OnGetMapImageAsyncCompleted, this, _1))
+    , m_async(std::bind(&MapCtrl::OnGetMapImageAsyncCompleted, this, std::placeholders::_1))
     , m_minimap(0)
     , m_metalmap(0)
     , m_heightmap(0)
@@ -149,6 +142,8 @@ MapCtrl::MapCtrl(wxWindow* parent, int size, IBattle* battle, bool readonly, boo
 
 MapCtrl::~MapCtrl()
 {
+	m_mutex.Lock();
+	m_async.Disconnect();
 	FreeMinimap();
 	delete m_close_img;
 	delete m_close_hi_img;
@@ -158,6 +153,9 @@ MapCtrl::~MapCtrl()
 	delete m_nfound_img;
 	delete m_reload_img;
 	delete m_dl_img;
+	delete m_player_img;
+	delete m_bot_img;
+	m_mutex.Unlock();
 }
 
 
@@ -362,7 +360,7 @@ void MapCtrl::_SetCursor()
 
 	if (m_battle != 0) {
 		const long longval = LSL::Util::FromIntString(m_battle->CustomBattleOptions()
-								     .getSingleValue("startpostype", LSL::Enum::EngineOption));
+								  .getSingleValue("startpostype", LSL::Enum::EngineOption));
 		if (longval != IBattle::ST_Choose) {
 			SetCursor(wxCursor(wxCURSOR_ARROW));
 			return;
@@ -456,7 +454,7 @@ int MapCtrl::LoadMinimap()
 	if (!m_battle->MapExists(false))
 		return -1;
 
-	const std::string map = m_battle->GetHostMapName();
+	const std::string& map = m_battle->GetHostMapName();
 
 	try {
 		int w, h;
@@ -469,12 +467,13 @@ int MapCtrl::LoadMinimap()
 
 		// start chain of asynchronous map image fetches
 		// first minimap, then metalmap and heightmap
-		m_async.GetMinimap(map, w, h);
+		m_async.GetMapImageAsync(map, LSL::IMAGE_MAP, w, h);
 
 		m_mapname = map;
 		m_lastsize = wxSize(w, h);
 	} catch (...) {
 		FreeMinimap();
+		m_mutex.Unlock();
 		return -3;
 	}
 	return 0;
@@ -511,13 +510,13 @@ void MapCtrl::UpdateMinimap()
 		if (!just_resize && loaded_ok == 0) // if a new map is loaded, reset start positions
 		{
 			const long longval = LSL::Util::FromIntString(m_battle->CustomBattleOptions()
-										 .getSingleValue("startpostype", LSL::Enum::EngineOption));
+									  .getSingleValue("startpostype", LSL::Enum::EngineOption));
 			if (longval == IBattle::ST_Pick)
 				RelocateUsers();
 		}
 	}
-	m_mutex.Unlock();
 	Refresh();
+	m_mutex.Unlock();
 }
 
 
@@ -774,7 +773,7 @@ void MapCtrl::DrawStartPositions(wxDC& dc)
 	m_map = m_battle->LoadMap();
 	RequireImages();
 	const long longval = LSL::Util::FromIntString(m_battle->CustomBattleOptions()
-							     .getSingleValue("startpostype", LSL::Enum::EngineOption));
+							  .getSingleValue("startpostype", LSL::Enum::EngineOption));
 	if (longval == IBattle::ST_Fixed) {
 
 		wxFont f(7, wxFONTFAMILY_DEFAULT, wxFONTSTYLE_NORMAL, wxFONTWEIGHT_LIGHT);
@@ -932,8 +931,10 @@ void MapCtrl::DrawUser(wxDC& dc, User& user, bool selected, bool /*unused*/)
 			DrawStartRect(dc, -1, tmp, col, false);
 		}
 
-		wxBitmap bmp = icons().GetBitmap(icons().GetSideIcon(m_battle->GetHostGameName(), user.BattleStatus().side));
-		dc.DrawBitmap(bmp, r.x + siderect.x, r.y + siderect.y, true);
+		if (!m_battle->GetHostGameName().empty()) { //game isn't set -> no side known
+			wxBitmap bmp = IconsCollection::Instance()->GetFractionBmp(m_battle->GetHostGameName(), user.BattleStatus().side);
+			dc.DrawBitmap(bmp, r.x + siderect.x, r.y + siderect.y, true);
+		}
 
 		/* Draw the Ally Number numeric select */
 		wxRect updownallyrect = GetUserUpAllyButtonRect();
@@ -1011,7 +1012,7 @@ void MapCtrl::DrawUserPositions(wxDC& dc)
 		User* bot = 0;
 		for (unsigned int bi = 0; bi < m_battle->GetNumUsers(); bi++) {
 			User& tbot = m_battle->GetUser(bi);
-			if (&tbot == 0)
+			if (tbot.BattleStatus().spectator)
 				continue;
 			if ((tbot.BattleStatus().pos.x == m_map.info.positions[i].x) && (tbot.BattleStatus().pos.y == m_map.info.positions[i].y)) {
 				bot = &tbot;
@@ -1027,8 +1028,6 @@ void MapCtrl::DrawUserPositions(wxDC& dc)
 	int previousteam = -1;
 	for (unsigned int i = 0; i < m_battle->GetNumUsers(); i++) {
 		User& usr = m_battle->GetUser(i);
-		if (&usr == 0)
-			continue;
 		if (usr.BattleStatus().spectator)
 			continue;
 		int currentteam = usr.BattleStatus().team;
@@ -1058,7 +1057,7 @@ void MapCtrl::OnPaint(wxPaintEvent& WXUNUSED(event))
 	if (!m_minimap)
 		return;
 	const long longval = LSL::Util::FromIntString(m_battle->CustomBattleOptions()
-							     .getSingleValue("startpostype", LSL::Enum::EngineOption));
+							  .getSingleValue("startpostype", LSL::Enum::EngineOption));
 
 
 	if (m_draw_start_types) {
@@ -1099,7 +1098,7 @@ void MapCtrl::OnMouseMove(wxMouseEvent& event)
 	if (p == wxDefaultPosition)
 		return;
 	const long longval = LSL::Util::FromIntString(m_battle->CustomBattleOptions()
-							     .getSingleValue("startpostype", LSL::Enum::EngineOption));
+							  .getSingleValue("startpostype", LSL::Enum::EngineOption));
 
 	if (longval == IBattle::ST_Pick) {
 
@@ -1107,11 +1106,6 @@ void MapCtrl::OnMouseMove(wxMouseEvent& event)
 			return;
 		if (m_maction == Moved) {
 			User& user = *m_user_expanded;
-			try {
-				ASSERT_LOGIC(&user != 0, "MapCtrl::OnMouseMove(): user = 0");
-			} catch (...) {
-				return;
-			}
 			m_map = m_battle->LoadMap();
 
 			wxRect mr = GetMinimapRect();
@@ -1137,13 +1131,8 @@ void MapCtrl::OnMouseMove(wxMouseEvent& event)
 		if (!m_user_expanded || !m_battle->UserExists(m_user_expanded->GetNick()))
 			m_user_expanded = 0;
 
-		if (m_user_expanded) {
+		if (m_user_expanded != nullptr) {
 			User& user = *m_user_expanded;
-			try {
-				ASSERT_LOGIC(&user != 0, "MapCtrl::OnMouseMove(): user = 0");
-			} catch (...) {
-				return;
-			}
 			wxRect r = GetUserRect(user, true);
 			if (r.Contains(event.GetX(), event.GetY())) {
 				RectangleArea last = m_rect_area;
@@ -1157,8 +1146,6 @@ void MapCtrl::OnMouseMove(wxMouseEvent& event)
 		} else {
 			for (unsigned int i = 0; i < m_battle->GetNumUsers(); i++) {
 				User& user = m_battle->GetUser(i);
-				if (&user == 0)
-					continue;
 				wxRect r = GetUserRect(user, false);
 				if (r.Contains(event.GetX(), event.GetY())) {
 					m_rect_area = GetUserRectArea(r, event.GetX(), event.GetY());
@@ -1301,7 +1288,7 @@ void MapCtrl::OnLeftDown(wxMouseEvent& event)
 		return;
 
 	const long longval = LSL::Util::FromIntString(m_battle->CustomBattleOptions()
-							     .getSingleValue("startpostype", LSL::Enum::EngineOption));
+							  .getSingleValue("startpostype", LSL::Enum::EngineOption));
 
 	if (!m_ro) {
 		if (longval == IBattle::ST_Pick) {
@@ -1313,12 +1300,9 @@ void MapCtrl::OnLeftDown(wxMouseEvent& event)
 				m_maction = Moved;
 			else
 				m_maction = None;
-			User& user = *m_user_expanded;
-			try {
-				ASSERT_LOGIC(&user != 0, "MapCtrl::OnLeftDown(): user = 0");
-			} catch (...) {
+			if (m_user_expanded == nullptr)
 				return;
-			}
+			User& user = *m_user_expanded;
 			RefreshRect(GetUserRect(user, true), false);
 			return;
 		}
@@ -1384,18 +1368,13 @@ void MapCtrl::OnLeftUp(wxMouseEvent& event)
 		return;
 
 	const long longval = LSL::Util::FromIntString(m_battle->CustomBattleOptions()
-							     .getSingleValue("startpostype", LSL::Enum::EngineOption));
+							  .getSingleValue("startpostype", LSL::Enum::EngineOption));
 	if (longval == IBattle::ST_Pick) {
-		if (!m_user_expanded)
+		if (m_user_expanded == nullptr)
 			return;
 		if (m_rect_area != m_mdown_area)
 			return;
 		User& user = *m_user_expanded;
-		try {
-			ASSERT_LOGIC(&user != 0, "MapCtrl::OnLeftUp(): user == 0");
-		} catch (...) {
-			return;
-		}
 		if ((m_mdown_area == Move) && (m_maction == Moved)) {
 			m_battle->UserPositionChanged(user);
 		} else if (m_mdown_area == UpAllyButton) {
@@ -1444,16 +1423,9 @@ void MapCtrl::OnLeftUp(wxMouseEvent& event)
 		if (m_mdown_area == m_rect_area) {
 			if (m_mdown_area == Refreshing) {
 				//				LSL::usync().AddReloadEvent();
-				m_battle->Update(stdprintf("%d_mapname", LSL::Enum::PrivateOptions));
 				UpdateMinimap();
 			} else if (m_mdown_area == Download) {
-				ContentDownloadRequest req;
-				req.MapRequired(m_battle->GetHostMapName(), m_battle->GetHostMapHash());
-				try{
-					ContentManager::Instance()->DownloadContent(req);
-				}catch(Exception& e) {
-					wxLogError(_("Failed to download map: ") + e.Reason());
-				}
+				ui().NeedsDownload(m_battle, false, DownloadEnum::CAT_MAP);
 			}
 		}
 		m_mdown_area = Main;
@@ -1503,7 +1475,7 @@ void MapCtrl::OnRightUp(wxMouseEvent& event)
 		return;
 
 	const long longval = LSL::Util::FromIntString(m_battle->CustomBattleOptions()
-							     .getSingleValue("startpostype", LSL::Enum::EngineOption));
+							  .getSingleValue("startpostype", LSL::Enum::EngineOption));
 	if (longval == IBattle::ST_Pick) {
 
 		if (!m_battle->MapExists(false))
@@ -1534,7 +1506,6 @@ void MapCtrl::OnRightUp(wxMouseEvent& event)
 						bs.ally = m_battle->GetFreeAlly();
 						bs.colour = m_battle->GetNewColour();
 						User& bot = m_battle->OnBotAdded(STD_STRING(dlg.GetNick()), bs);
-						ASSERT_LOGIC(&bot != 0, "bot == 0");
 						bot.BattleStatus().pos.x = x;
 						bot.BattleStatus().pos.y = y;
 						RefreshRect(GetUserRect(bot, false), false);
@@ -1567,10 +1538,14 @@ void MapCtrl::OnMouseWheel(wxMouseEvent& event)
 
 void MapCtrl::OnGetMapImageAsyncCompleted(const std::string& mapname)
 {
-	wxLogDebug(wxString::Format(_T("Map loaded (async) complete: %s"), TowxString(mapname).c_str()));
 	m_mutex.Lock();
+	wxLogDebug(wxString::Format(_T("Map loaded (async) complete: %s"), TowxString(mapname).c_str()));
+	if (!m_async.Connected()) { //was closed, abort
+		m_mutex.Unlock();
+		return;
+	}
 
-	if (m_mapname.empty() || mapname.empty() || mapname != m_mapname) {
+	if (m_mapname.empty() || mapname.empty() || mapname != m_mapname) { //selected doesn't match fetched map, abort
 		m_mutex.Unlock();
 		return;
 	}
@@ -1579,19 +1554,19 @@ void MapCtrl::OnGetMapImageAsyncCompleted(const std::string& mapname)
 	const int h = m_lastsize.GetHeight();
 
 	if (m_minimap == NULL) {
-		m_minimap = new wxBitmap(LSL::usync().GetMinimap(m_mapname, w, h).wxbitmap());
+		m_minimap = new wxBitmap(LSL::usync().GetScaledMapImage(mapname, LSL::IMAGE_MAP, w, h).wxbitmap());
 		// this ensures metalmap and heightmap aren't loaded in battlelist
 		if (m_draw_start_types) {
-			m_async.GetMetalmap(m_mapname, w, h);
+			m_async.GetMapImageAsync(mapname, LSL::IMAGE_MAP, w, h);
 		}
 	} else if (m_metalmap == NULL) {
-		m_metalmap = new wxBitmap(LSL::usync().GetMetalmap(m_mapname, w, h).wxbitmap());
+		m_metalmap = new wxBitmap(LSL::usync().GetScaledMapImage(mapname, LSL::IMAGE_METALMAP, w, h).wxbitmap());
 		// singleplayer mode doesn't allow startboxes anyway
-		m_metalmap_cumulative = LSL::usync().GetMetalmap(m_mapname, w, h).wximage();
+		m_metalmap_cumulative = LSL::usync().GetScaledMapImage(mapname, LSL::IMAGE_METALMAP, w, h).wximage();
 		Accumulate(m_metalmap_cumulative);
-		m_async.GetHeightmap(m_mapname, w, h);
+		m_async.GetMapImageAsync(mapname, LSL::IMAGE_HEIGHTMAP, w, h);
 	} else if (m_heightmap == NULL) {
-		m_heightmap = new wxBitmap(LSL::usync().GetHeightmap(m_mapname, w, h).wxbitmap());
+		m_heightmap = new wxBitmap(LSL::usync().GetScaledMapImage(mapname, LSL::IMAGE_HEIGHTMAP, w, h).wxbitmap());
 	}
 
 	// never ever call a gui function here, it will crash! (in 1/100 cases)
