@@ -1,19 +1,19 @@
 /* This file is part of the Springlobby (GPL v2 or later), see COPYING */
+#include "ToasterBoxWindow.h"
 
-#include <wx/dialog.h>
-#include <wx/utils.h>
-#include <wx/string.h>
 #include <wx/bitmap.h>
-#include <wx/timer.h>
-#include <wx/dcclient.h>
-#include <wx/region.h>
 #include <wx/dcbuffer.h>
+#include <wx/dcclient.h>
+#include <wx/dialog.h>
 #include <wx/frame.h>
 #include <wx/log.h>
+#include <wx/region.h>
+#include <wx/string.h>
+#include <wx/timer.h>
+#include <wx/utils.h>
 
-#include "ToasterBoxWindow.h"
-#include "images/notif_bg.png.h"
 #include "gui/uiutils.h"
+#include "images/notif_bg.png.h"
 
 typedef wxClientDC DCType;
 
@@ -30,17 +30,18 @@ ToasterBoxWindow::ToasterBoxWindow(wxWindow* parent, wxTimer* _parent2)
     , sleepTime(10)
     , pauseTime(1700)
     , textColor(*wxWHITE)
+    , headerTextColor(*wxBLUE)
     , popupText(_T("Change Me!"))
     , shrink(false)
 {
-	Create(parent, wxID_ANY);
+	Create(parent);
 	SetWindowStyleFlag(wxNO_BORDER | wxSTAY_ON_TOP | wxFRAME_NO_TASKBAR);
 	count++;
 	//the size we want the dialog to be
 	wxSize dialogSize(150, 170);
 	bottomRight = wxPoint(wxGetDisplaySize().GetWidth(), wxGetDisplaySize().GetHeight());
 	SetSize(bottomRight.x, bottomRight.y, dialogSize.GetWidth(), dialogSize.GetHeight());
-	ToasterBase::Connect(wxEVT_PAINT, (wxObjectEventFunction)&ToasterBoxWindow::OnPaint);
+//	ToasterBase::Connect(wxEVT_PAINT, (wxObjectEventFunction)&ToasterBoxWindow::OnPaint);
 	SetBackgroundBitmap(charArr2wxBitmap(notif_bg_png, sizeof(notif_bg_png)));
 }
 
@@ -85,7 +86,7 @@ void ToasterBoxWindow::SetPopupPosition(int x, int y)
 
 //_shrink indicates if we should to transformations on
 //the text to make it "pretty"
-void ToasterBoxWindow::SetPopupText(wxString _text, bool _shrink)
+void ToasterBoxWindow::SetPopupText(const wxString& _text, bool _shrink)
 {
 	popupText = _text;
 	shrink = _shrink;
@@ -193,9 +194,9 @@ void ToasterBoxWindow::DrawText()
 	//border from sides and top to text (in pixels)
 	int border_right = 7;
 	int border_left = 102;
-	if (sbm.GetBitmap().IsOk()) {
-		border_left += sbm.GetBitmap().GetWidth();
-	}
+//	if (sbm.GetBitmap().IsOk()) {
+//		border_left += sbm.GetBitmap().GetWidth();
+//	}
 	//how much space between text lines
 	int textPadding = 4;
 	//how much can we have on a line?
@@ -220,28 +221,50 @@ void ToasterBoxWindow::DrawText()
 		textLines = (GetPopupText().Length() / textColumns) + .9;
 	}
 
+	bool haveHeader = false;
+	if (popupHeaderText.IsEmpty() == false) {
+		textLines++;
+		haveHeader = true;
+	}
 	//center the text
 	//  if(w < GetSize().GetWidth())
 	//    x = (GetSize().GetWidth() - w) / 2;
 	//  if(h < GetSize().GetHeight())
 	//    y = (GetSize().GetHeight() - h) / 2;
 
-	dc.SetTextForeground(textColor);
 
 	//  //if we have multiple lines
 	if (textLines > 1) {
+		if (haveHeader) {
+			//Draw header text with a shadow effect
+			dc.SetTextForeground(*wxGREEN);
+			//Try to center header text
+			auto textSize = dc.GetTextExtent(popupHeaderText);
+			int headerX = (GetSize().GetWidth() / 2) - (textSize.GetWidth() / 2);
+			const int headerY = 3;
+			dc.DrawText(popupHeaderText, headerX, headerY);
+			dc.SetTextForeground(headerTextColor);
+			dc.DrawText(popupHeaderText, headerX + 1, headerY + 1); //This makes "shadow" effect
+		}
+		dc.SetTextForeground(textColor);
 		//how many lines we can fit in the height available
 		float howManyLinesFit = GetSize().GetHeight() / (h + textPadding);
 		if (textLines < howManyLinesFit)
 			howManyLinesFit = textLines;
 		y = (GetSize().GetHeight() - ((h + textPadding) * howManyLinesFit)) / 2;
+		//Move text down a bit to get place for header
+		if (haveHeader) {
+			y += 15;
+		}
 		for (int i = 0; i < howManyLinesFit; i++) {
 			dc.DrawText(GetPopupText().Mid((i * textColumns), textColumns), x + border_left, y);
 			//move the text down a line
 			y += h + textPadding;
 		}
-	} else
+	} else {
+		dc.SetTextForeground(textColor);
 		dc.DrawText(pText, x, y);
+	}
 }
 
 void ToasterBoxWindow::Notify()
@@ -261,3 +284,8 @@ void ToasterBoxWindow::OnPaint(wxPaintEvent& /*event*/)
 {
 	DrawText();
 }
+
+void ToasterBoxWindow::SetPopupHeaderText(const wxString& _header)
+{
+	popupHeaderText = _header;
+}
