@@ -16,7 +16,10 @@ public:
 	virtual int Compare(const wxDataViewItem& itemA, const wxDataViewItem& itemB, unsigned int column, bool ascending) const override;
 	virtual void GetValue(wxVariant& variant, const wxDataViewItem& item, unsigned int col) const override;
 	virtual wxString GetColumnType(unsigned int columnt) const override;
-	virtual bool HasDefaultCompare() const override { return true; }
+	virtual bool HasDefaultCompare() const override
+	{
+		return true;
+	}
 
 private:
 	enum ColumnIndexes {
