@@ -1,33 +1,32 @@
 /* This file is part of the Springlobby (GPL v2 or later), see COPYING */
+#include "playbackfilter.h"
 
+#include <wx/button.h>
+#include <wx/checkbox.h>
+#include <wx/choice.h>
+#include <wx/event.h>
+#include <wx/intl.h>
+#include <wx/regex.h>
+#include <wx/sizer.h>
+#include <wx/statbox.h>
+#include <wx/stattext.h>
+#include <wx/string.h>
+#include <wx/textctrl.h>
 #if wxUSE_TOGGLEBTN
 #include <wx/tglbtn.h>
 #endif
-#include <wx/stattext.h>
-#include <wx/checkbox.h>
-#include <wx/sizer.h>
-#include <wx/textctrl.h>
-#include <wx/intl.h>
-#include <wx/choice.h>
-#include <wx/button.h>
-#include <wx/string.h>
-#include <wx/statbox.h>
-#include <wx/event.h>
-#include <wx/regex.h>
 
-#include "playbacktab.h"
-#include "replaylist.h"
-//#include "PlaybackListFiltervalues.h"
-#include "playbackfiltervalues.h"
 #include "battle.h"
 #include "gui/uiutils.h"
-#include "utils/tasutil.h"
-#include "utils/conversion.h"
-#include "settings.h"
 #include "offlinebattle.h"
-#include "playbackfilter.h"
+#include "playbackfiltervalues.h"
+#include "playbacktab.h"
+#include "replaylist.h"
+#include "settings.h"
 #include "storedgame.h"
-
+#include "utils/conversion.h"
+#include "utils/tasutil.h"
+//#include "PlaybackListFiltervalues.h"
 ///////////////////////////////////////////////////////////////////////////
 
 BEGIN_EVENT_TABLE(PlaybackListFilter, wxPanel)
@@ -83,7 +82,9 @@ PlaybackListFilter::PlaybackListFilter(wxWindow* parent, wxWindowID id, Playback
 		m_filter_player_choiceChoices.Add(i.ToString());
 
 	m_filter_player_choice = new wxChoice(this, PLAYBACK_FILTER_PLAYER_CHOICE, wxDefaultPosition, wxSize(-1, -1), m_filter_player_choiceChoices, 0);
-	m_filter_player_choice->SetSelection(GetIntParam(f_values.player_num));
+	long value = 0;
+	value = f_values.player_num.ToLong(&value);
+	m_filter_player_choice->SetSelection(value);
 	if (m_filter_player_choice->GetSelection() == -1)
 		m_filter_player_choice->SetSelection(0);
 
@@ -249,6 +250,12 @@ PlaybackListFilter::PlaybackListFilter(wxWindow* parent, wxWindowID id, Playback
 	OnChange(dummy);
 }
 
+PlaybackListFilter::~PlaybackListFilter()
+{
+	delete m_filter_map_expression;
+	delete m_filter_mod_expression;
+}
+
 PlaybackListFilter::m_button_mode PlaybackListFilter::_GetButtonMode(wxString sign)
 {
 	if (sign == _T("<"))
@@ -423,7 +430,7 @@ void PlaybackListFilter::SaveFilterValues()
 	filtervalues.mod = m_filter_mod_edit->GetValue();
 	filtervalues.mod_show = m_filter_mod_show->GetValue();
 	filtervalues.player_mode = _GetButtonSign(m_filter_player_mode);
-	filtervalues.player_num = wxString::Format(_("%d"), m_filter_player_choice->GetSelection());
+	filtervalues.player_num = wxString::Format(_T("%d"), m_filter_player_choice->GetSelection());
 	filtervalues.duration_mode = _GetButtonSign(m_filter_duration_mode);
 	filtervalues.filesize = m_filter_filesize_edit->GetValue();
 	filtervalues.filesize_mode = _GetButtonSign(m_filter_filesize_mode);
