@@ -3,32 +3,32 @@
 #ifndef SPRINGLOBBY_HEADERGUARD_TASKBAR_H
 #define SPRINGLOBBY_HEADERGUARD_TASKBAR_H
 
-#include <wx/gauge.h>
 #include <wx/panel.h>
-#include <wx/stattext.h>
-#include <wx/event.h>
-#include <wx/timer.h>
+class wxTimer;
+class wxStaticText;
+class wxGauge;
+class wxTimerEvent;
 
 class TaskBar : public wxPanel
 {
 public:
 	TaskBar(wxWindow* parent);
 	~TaskBar();
-	void OnTimer(wxTimerEvent& /*event*/);
 
 private:
-	void UpdateDisplay();
+	void OnDownloadStarted(wxCommandEvent& event);
+	void OnDownloadComplete(wxCommandEvent& event);
+	void OnDownloadFailed(wxCommandEvent& event);
+	void OnDownloadProgress(wxCommandEvent& event);
+
 	void UpdateProgress();
+	void OnTimer(wxTimerEvent&);
+	void EnsureTimerRemoved();
 
 	wxTimer* timer;
 	wxStaticText* text;
 	wxGauge* gauge;
-	int state;
-	wxString downloadName;
-	int overalSize;
-	unsigned int overalProgress;
-	int unfinishedTasks;
-	int finishedCounter;
+
 	DECLARE_EVENT_TABLE()
 };
 
