@@ -345,6 +345,11 @@ void Ui::OnChannelMessage(Channel& chan, const std::string& msg)
 	}
 }
 
+void Ui::OnBattleMessage(IBattle& /*battle*/, const std::string& msg)
+{
+	mw().GetJoinTab().GetBattleRoomTab().GetChatPanel().StatusMessage(TowxString(msg));
+}
+
 void Ui::OnChannelList(const wxString& channel, const int& numusers)
 {
 	ChatPanel* panel = GetActiveChatPanel();
@@ -617,6 +622,16 @@ void Ui::OnUserBattleStatus(User& user)
 	OnBattleInfoUpdated(*battle, wxEmptyString);
 }
 
+void Ui::OnBattleTopic(IBattle& /*battle*/, const wxString& who, const wxString& msg)
+{
+	if (m_main_win == 0)
+		return;
+	try {
+		mw().GetJoinTab().GetBattleRoomTab().GetChatPanel().SetTopic(who, msg);
+	} catch (...) {
+	}
+}
+
 void Ui::OnSaidBattle(IBattle& /*battle*/, const wxString& nick, const wxString& msg)
 {
 	if (m_main_win == 0)
@@ -652,9 +667,10 @@ void Ui::OnSpringTerminated(wxCommandEvent& data)
 
 void Ui::OnAcceptAgreement(const wxString& agreement)
 {
-	AgreementDialog dlg(m_main_win, agreement);
+	std::string verif_code;
+	AgreementDialog dlg(m_main_win, agreement, &verif_code);
 	if (dlg.ShowModal() == wxID_OK) {
-		m_serv->AcceptAgreement();
+		m_serv->AcceptAgreement(verif_code);
 	} else {
 		m_connect_retries = 0;
 		m_serv->Disconnect();
