@@ -65,6 +65,7 @@ public:
 
 	void OnJoinedChannelSuccessful(Channel& chan, bool doFocus = false);
 	void OnChannelMessage(Channel& chan, const std::string& msg);
+	void OnBattleMessage(IBattle& chan, const std::string& msg);
 
 	void OnChannelList(const wxString& channel, const int& numusers);
 	void OnUserOnline(User& user);
@@ -88,6 +89,8 @@ public:
 	void OnHostedBattle(IBattle& battle);
 	void OnUserBattleStatus(User& user);
 
+	void OnNoBattleTopic(IBattle& battle, const wxString& who);
+	void OnBattleTopic(IBattle& battle, const wxString& who, const wxString& message);
 	void OnSaidBattle(IBattle& battle, const wxString& nick, const wxString& msg);
 
 	void OnSpringTerminated(wxCommandEvent& data);
