@@ -33,8 +33,7 @@ namespace LSL
 class OptionsWrapper;
 };
 
-struct BattleStartRect
-{
+struct BattleStartRect {
 	BattleStartRect()
 	    : toadd(false)
 	    , todelete(false)
@@ -80,10 +79,10 @@ enum BattleType {
 };
 
 
-struct BattleOptions
-{
+struct BattleOptions {
 	BattleOptions()
 	    : battleid(-1)
+	    , channel_name("")
 	    , islocked(false)
 	    , battletype(BT_Played)
 	    , ispassworded(false)
@@ -101,6 +100,7 @@ struct BattleOptions
 	}
 
 	int battleid;
+	std::string channel_name;
 	bool islocked;
 	BattleType battletype;
 	bool ispassworded;
@@ -185,8 +185,7 @@ public:
 	};
 
 
-	struct TeamInfoContainer
-	{
+	struct TeamInfoContainer {
 		bool exist;
 		int TeamLeader;
 		int StartPosX;
@@ -198,8 +197,7 @@ public:
 		int SideNum;
 	};
 
-	struct AllyInfoContainer
-	{
+	struct AllyInfoContainer {
 		bool exist;
 		int NumAllies;
 		int StartRectLeft;
@@ -340,6 +338,11 @@ public:
 		return m_opts.battleid;
 	}
 
+	virtual std::string GetChannelName() const
+	{
+		return m_opts.channel_name;
+	}
+
 	virtual bool GetGUIListActiv() const
 	{
 		return m_opts.guilistactiv;
