@@ -6,6 +6,10 @@
 #include <string>
 #include <wx/log.h>
 
+#define PRD_LOG_COMPONENT "prd"
+
+const char* wxLogLevelToString(wxLogLevel level);
+
 class wxString;
 class wxLogWindow;
 class wxWindow;
@@ -36,10 +40,10 @@ public:
 	}
 };
 
-#define ASSERT_LOGIC(cond, msg)                                                                                                                 \
-	if (!(cond)) {                                                                                                                          \
-		wxLogError(wxString::Format(_T("logic error ( %s:%d ): %s"), TowxString(__FILE__).c_str(), __LINE__, TowxString(msg).c_str())); \
-		throw std::logic_error(msg);                                                                                                    \
+#define ASSERT_LOGIC(cond, msg)                                                                                                                   \
+	if (!(cond)) {                                                                                                                            \
+		wxLogWarning(wxString::Format(_T("logic error ( %s:%d ): %s"), TowxString(__FILE__).c_str(), __LINE__, TowxString(msg).c_str())); \
+		throw std::logic_error(msg);                                                                                                      \
 	}
 
 #define ASSERT_EXCEPTION(cond, msg)                                                                                                 \
