@@ -1,13 +1,13 @@
 /* This file is part of the Springlobby (GPL v2 or later), see COPYING */
+#include "playbackthread.h"
 
+#include <lslunitsync/unitsync.h>
 #include <wx/app.h>
 #include <wx/log.h>
 
+#include "gui/playback/playbacktab.h"
 #include "replaylist.h"
 #include "savegamelist.h"
-#include "playbackthread.h"
-#include "gui/playback/playbacktab.h"
-#include <lslunitsync/unitsync.h>
 
 PlaybackLoader::PlaybackLoader(PlaybackTab* parent, bool IsReplayType)
     : wxEvtHandler()
@@ -27,13 +27,12 @@ PlaybackLoader::~PlaybackLoader()
 
 void PlaybackLoader::Run()
 {
-	if (!LSL::usync().IsLoaded())
-		return;
+	assert(LSL::usync().IsLoaded());
+
 	if (m_thread_loader)
 		return; // a thread is already running
-	m_filenames = LSL::usync().GetPlaybackList(m_isreplaytype);
-	replaylist().RemoveAll();
-	m_thread_loader = new PlaybackLoaderThread(this, m_parent);
+
+	m_thread_loader = new PlaybackLoaderThread(this, m_parent, m_isreplaytype);
 	m_thread_loader->Create();
 	m_thread_loader->Run();
 }
@@ -47,14 +46,10 @@ void PlaybackLoader::OnComplete()
 	m_thread_loader = NULL; // the thread object deleted itself
 }
 
-std::vector<std::string> PlaybackLoader::GetPlaybackFilenames()
-{
-	return m_filenames;
-}
-
-PlaybackLoader::PlaybackLoaderThread::PlaybackLoaderThread(PlaybackLoader* loader, PlaybackTab* parent)
+PlaybackLoader::PlaybackLoaderThread::PlaybackLoaderThread(PlaybackLoader* loader, PlaybackTab* parent, bool isreplaytype)
     : m_parent(parent)
     , m_loader(loader)
+    , m_isreplaytype(isreplaytype)
 {
 	assert(m_parent != NULL);
 }
@@ -62,9 +57,14 @@ PlaybackLoader::PlaybackLoaderThread::PlaybackLoaderThread(PlaybackLoader* loade
 void* PlaybackLoader::PlaybackLoaderThread::Entry()
 {
 	if (m_parent) {
-		replaylist().LoadPlaybacks(m_loader->GetPlaybackFilenames());
+		std::set<std::string> filenames;
+		if (!LSL::usync().GetPlaybackList(filenames, m_isreplaytype)) {
+			wxLogWarning("Couldn't load list of playbacks.");
+			return nullptr;
+		}
+		replaylist().LoadPlaybacks(filenames);
 		m_loader->OnComplete();
 	}
 
-	return NULL;
+	return nullptr;
 }
