@@ -2,8 +2,8 @@
 
 #include "savegamelist.h"
 
-#include <fstream>
 #include <wx/filename.h>
+#include <fstream>
 
 #include "storedgame.h"
 #include "utils/conversion.h"
@@ -13,27 +13,12 @@ SavegameList::SavegameList()
 }
 
 
-void SavegameList::LoadPlaybacks(const std::vector<std::string>& filenames)
-{
-	m_replays.clear();
-	const size_t size = filenames.size();
-	for (size_t i = 0; i < size; ++i) {
-		const std::string fn = filenames[i];
-		StoredGame& rep_ref = AddPlayback(i);
-
-		if (!GetSavegameInfos(fn, rep_ref)) {
-			RemovePlayback(rep_ref.id);
-		}
-	}
-}
-
 bool SavegameList::GetSavegameInfos(const std::string& SavegamePath, StoredGame& ret) const
 {
 	//wxLogMessage(_T("GetSavegameInfos %s"), SavegamePath.c_str());
 	//wxLOG_Info  ( STD_STRING( SavegamePath ) );
 	//TODO extract moar info
 	ret.type = StoredGame::SAVEGAME;
-	ret.Filename = SavegamePath;
 	ret.battle.SetPlayBackFilePath(SavegamePath);
 	if (SavegamePath.empty())
 		return false;
@@ -44,7 +29,6 @@ bool SavegameList::GetSavegameInfos(const std::string& SavegamePath, StoredGame&
 		return false;
 
 	ret.battle.GetBattleFromScript(false);
-	ret.GameName = ret.battle.GetHostGameName();
 	ret.battle.SetBattleType(BT_Savegame);
 	ret.size = wxFileName::GetSize(TowxString(SavegamePath)).ToULong();
 
