@@ -40,7 +40,7 @@
 
 void ServerEvents::OnConnected(const std::string& server_name, const std::string& server_ver, bool supported, const std::string& server_spring_ver, bool /*unused*/)
 {
-	wxLogInfo("Connected to %s %s %s",m_serv.m_serverinfo.hostname.c_str(),  server_ver.c_str(), server_spring_ver.c_str());
+	wxLogInfo("Connected to %s %s %s", m_serv.m_serverinfo.hostname.c_str(), server_ver.c_str(), server_spring_ver.c_str());
 	//Server version will include patchlevel from release 89 onwards
 	m_serv.SetRequiredSpring(LSL::Util::BeforeFirst(server_spring_ver, "."));
 	ui().OnConnected(m_serv, TowxString(server_name), TowxString(server_spring_ver), supported);
@@ -125,7 +125,7 @@ void ServerEvents::OnPong(wxLongLong ping_time)
 }
 
 
-void ServerEvents::OnNewUser(const std::string& nick, const std::string& country, int cpu, int id)
+void ServerEvents::OnNewUser(const std::string& nick, const std::string& country, int id, const std::string& clientAgent)
 {
 	slLogDebugFunc("");
 	if (m_serv.UserExists(nick)) {
@@ -134,8 +134,8 @@ void ServerEvents::OnNewUser(const std::string& nick, const std::string& country
 	}
 	User& user = m_serv._AddUser(nick);
 	user.SetCountry(country);
-	user.SetCpu(cpu);
 	user.SetID(id);
+	user.SetClientAgent(clientAgent);
 	if (!m_serv.IsOnline()) { //login info isn't complete yet
 		return;
 	}
@@ -221,12 +221,13 @@ void ServerEvents::OnUserQuit(const std::string& nick)
 void ServerEvents::OnBattleOpened(int id, BattleType type, NatType nat, const std::string& nick,
 				  const std::string& host, int port, int maxplayers,
 				  bool haspass, int rank, const std::string& maphash, const std::string& engineName, const std::string& engineVersion, const std::string& map,
-				  const std::string& title, const std::string& mod)
+				  const std::string& title, const std::string& mod,
+				  const std::string& channelName)
 {
 	slLogDebugFunc("");
 	try {
 		ASSERT_EXCEPTION(!m_serv.BattleExists(id), _T("New battle from server, but already exists!"));
-		IBattle& battle = m_serv._AddBattle(id);
+		IBattle& battle = m_serv._AddBattle(id, channelName);
 
 		User& user = m_serv.GetUser(nick);
 		battle.OnUserAdded(user);
@@ -244,7 +245,6 @@ void ServerEvents::OnBattleOpened(int id, BattleType type, NatType nat, const st
 		battle.SetHostGame(mod, "");
 		battle.SetEngineName(engineName);
 		battle.SetEngineVersion(engineVersion);
-
 		if (useractions().DoActionOnUser(UserActions::ActNotifBattle, TowxString(user.GetNick()))) {
 			actNotifBox(SL_MAIN_ICON, TowxString(user.GetNick()) + _(" opened battle ") + TowxString(title));
 		}
@@ -307,7 +307,7 @@ void ServerEvents::OnHostedBattle(int battleid)
 		m_serv.SendHostInfo(IBattle::HI_Send_All_opts);
 
 		ui().OnHostedBattle(battle);
-	} catch (assert_exception) {
+	} catch (assert_exception&) {
 	}
 }
 
@@ -373,9 +373,21 @@ void ServerEvents::OnUserLeftBattle(int battleid, const std::string& nick)
 		User& user = battle.GetUser(nick);
 		// this is necessary since the user will be deleted when the gui function is called
 		bool isbot = user.BattleStatus().IsBot();
+		std::map<std::string, User*> user_map = battle.GetUsers();
 		user.BattleStatus().scriptPassword.clear();
 		battle.OnUserRemoved(user);
 		ui().OnUserLeftBattle(battle, user, isbot);
+
+		for (auto p : user_map) { // remove any bridged users that we no longer share channels with
+			User& user = *p.second;
+			if (!user.IsBridged())
+				continue;
+			std::string nick = p.first;
+			if (!m_serv.UserIsOnBridge(nick)) {
+				ui().OnUserOffline(user);
+				m_serv._RemoveUser(nick);
+			}
+		}
 	} catch (std::runtime_error& except) {
 	}
 }
@@ -400,7 +412,7 @@ void ServerEvents::OnBattleInfoUpdated(int battleid, int spectators, bool locked
 		}
 
 		ui().OnBattleInfoUpdated(battle, wxEmptyString);
-	} catch (assert_exception) {
+	} catch (assert_exception&) {
 		wxLogWarning("Exception in OnBattleInfoUpdated");
 	}
 }
@@ -551,7 +563,7 @@ void ServerEvents::OnBattleInfoUpdated(int battleid)
 	try {
 		IBattle& battle = m_serv.GetBattle(battleid);
 		ui().OnBattleInfoUpdated(battle, wxEmptyString);
-	} catch (assert_exception) {
+	} catch (assert_exception&) {
 		wxLogWarning("Exception in OnBattleInfoUpdated(%d)", battleid);
 	}
 }
@@ -560,13 +572,17 @@ void ServerEvents::OnBattleInfoUpdated(int battleid)
 void ServerEvents::OnBattleClosed(int battleid)
 {
 	slLogDebugFunc("");
-	if (!m_serv.BattleExists(battleid)) {
-		wxLogWarning("Tried to close non-existing battle %d", battleid);
-		return;
+	try {
+		if (!m_serv.BattleExists(battleid)) {
+			wxLogWarning("Tried to close non-existing battle %d", battleid);
+			return;
+		}
+		IBattle& battle = m_serv.GetBattle(battleid);
+		ui().OnBattleClosed(battle);
+		m_serv._RemoveBattle(battleid);
+	} catch (assert_exception&) {
+		wxLogWarning("Exception in OnBattleClosed(%d)", battleid);
 	}
-	IBattle& battle = m_serv.GetBattle(battleid);
-	ui().OnBattleClosed(battle);
-	m_serv._RemoveBattle(battleid);
 }
 
 
@@ -577,7 +593,7 @@ void ServerEvents::OnBattleDisableUnit(int battleid, const std::string& unitname
 		IBattle& battle = m_serv.GetBattle(battleid);
 		battle.RestrictUnit(unitname, count);
 		wxLogDebug("OnBattleDisableUnit %d %s %d", battleid, unitname.c_str(), count);
-	} catch (assert_exception) {
+	} catch (assert_exception&) {
 	}
 }
 
@@ -588,7 +604,7 @@ void ServerEvents::OnBattleEnableUnit(int battleid, const std::string& unitname)
 	try {
 		IBattle& battle = m_serv.GetBattle(battleid);
 		battle.UnrestrictUnit(unitname);
-	} catch (assert_exception) {
+	} catch (assert_exception&) {
 	}
 }
 
@@ -599,7 +615,7 @@ void ServerEvents::OnBattleEnableAllUnits(int battleid)
 	try {
 		IBattle& battle = m_serv.GetBattle(battleid);
 		battle.UnrestrictAllUnits();
-	} catch (assert_exception) {
+	} catch (assert_exception&) {
 	}
 }
 
@@ -608,6 +624,9 @@ void ServerEvents::OnJoinChannelResult(bool success, const std::string& channel,
 {
 	slLogDebugFunc("");
 	if (success) {
+		int battleid = m_serv.m_battles.BattleFromChannel(channel);
+		if (battleid != -1) // if this channel is associated to a battle, don't show it as a standlone channel
+			return;
 		Channel& chan = m_serv._AddChannel(channel);
 		chan.SetPassword(m_serv.m_channel_pw[channel]);
 		ui().OnJoinedChannelSuccessful(chan);
@@ -622,6 +641,11 @@ void ServerEvents::OnChannelSaid(const std::string& channel, const std::string&
 {
 	slLogDebugFunc("");
 	try {
+		int battleid = m_serv.m_battles.BattleFromChannel(channel);
+		if (battleid != -1) {
+			OnBattleSaid(battleid, who, message);
+			return;
+		}
 		if ((m_serv.GetMe().GetNick() == who) || !useractions().DoActionOnUser(UserActions::ActIgnoreChat, TowxString(who))) {
 			if (m_serv.UserExists(who)) {
 				m_serv.GetChannel(channel).Said(m_serv.GetUser(who), message);
@@ -634,11 +658,29 @@ void ServerEvents::OnChannelSaid(const std::string& channel, const std::string&
 	}
 }
 
+void ServerEvents::OnBattleSaid(int battleid, const std::string& nick, const std::string& msg)
+{
+	try {
+		IBattle& battle = m_serv.GetBattle(battleid);
+		if ((m_serv.GetMe().GetNick() == nick) || !useractions().DoActionOnUser(UserActions::ActIgnoreChat, TowxString(nick))) {
+			ui().OnSaidBattle(battle, TowxString(nick), TowxString(msg));
+		}
+		AutoHost* ah = battle.GetAutoHost();
+		if (ah != NULL) {
+			ah->OnSaidBattle(TowxString(nick), TowxString(msg));
+		}
+	} catch (assert_exception&) {
+	}
+}
+
 
 void ServerEvents::OnChannelJoin(const std::string& channel, const std::string& who)
 {
 	slLogDebugFunc("");
 	try {
+		int battleid = m_serv.m_battles.BattleFromChannel(channel);
+		if (battleid != -1)
+			return;
 		m_serv.GetChannel(channel).OnChannelJoin(m_serv.GetUser(who));
 	} catch (std::runtime_error& except) {
 	}
@@ -649,16 +691,38 @@ void ServerEvents::OnChannelPart(const std::string& channel, const std::string&
 {
 	slLogDebugFunc("");
 	try {
-		m_serv.GetChannel(channel).Left(m_serv.GetUser(who), message);
+		int battleid = m_serv.m_battles.BattleFromChannel(channel);
+		if (battleid != -1)
+			return;
+		Channel& chan = m_serv.GetChannel(channel);
+		chan.Left(m_serv.GetUser(who), message);
+
+		std::map<std::string, User*> user_map = chan.GetUsers();
+		for (auto p : user_map) { // remove any bridged users that we no longer share channels with
+			User& user = *p.second;
+			if (!user.IsBridged())
+				continue;
+			std::string nick = p.first;
+			if (!m_serv.UserIsOnBridge(nick)) {
+				ui().OnUserOffline(user);
+				m_serv._RemoveUser(nick);
+			}
+		}
 	} catch (std::runtime_error& except) {
 	}
 }
 
 
-void ServerEvents::OnChannelTopic(const std::string& channel, const std::string& who, const std::string& message, int /*unused*/)
+void ServerEvents::OnChannelTopic(const std::string& channel, const std::string& who, const std::string& message)
 {
 	slLogDebugFunc("");
 	try {
+		int battleid = m_serv.m_battles.BattleFromChannel(channel);
+		if (battleid != -1) {
+			IBattle& battle = m_serv.GetBattle(battleid);
+			ui().OnBattleTopic(battle, message, who);
+			return;
+		}
 		m_serv.GetChannel(channel).SetTopic(message, who);
 	} catch (std::runtime_error& except) {
 	}
@@ -669,12 +733,25 @@ void ServerEvents::OnChannelAction(const std::string& channel, const std::string
 {
 	slLogDebugFunc("");
 	try {
+		int battleid = m_serv.m_battles.BattleFromChannel(channel);
+		if (battleid != -1) {
+			OnBattleAction(battleid, who, action);
+			return;
+		}
 		if ((m_serv.GetMe().GetNick() == who) || !useractions().DoActionOnUser(UserActions::ActIgnoreChat, TowxString(who)))
 			m_serv.GetChannel(channel).DidAction(m_serv.GetUser(who), action);
 	} catch (std::runtime_error& except) {
 	}
 }
 
+void ServerEvents::OnBattleAction(int /*battleid*/, const std::string& nick, const std::string& action)
+{
+	try {
+		UiEvents::GetUiEventSender(UiEvents::OnBattleActionEvent).SendEvent(UiEvents::OnBattleActionData(TowxString(nick), TowxString(action)));
+	} catch (assert_exception&) {
+	}
+}
+
 
 void ServerEvents::OnPrivateMessage(User& chan, User& who, const std::string& message)
 {
@@ -706,6 +783,9 @@ void ServerEvents::OnUserJoinChannel(const std::string& channel, const std::stri
 {
 	slLogDebugFunc("");
 	try {
+		int battleid = m_serv.m_battles.BattleFromChannel(channel);
+		if (battleid != -1) // don't display as a channel, if its a battle
+			return;
 		m_serv.GetChannel(channel).Joined(m_serv.GetUser(who));
 	} catch (std::runtime_error& except) {
 	}
@@ -717,32 +797,7 @@ void ServerEvents::OnRequestBattleStatus(int battleid)
 	try {
 		IBattle& battle = m_serv.GetBattle(battleid);
 		battle.OnRequestBattleStatus();
-	} catch (assert_exception) {
-	}
-}
-
-
-void ServerEvents::OnSaidBattle(int battleid, const std::string& nick, const std::string& msg)
-{
-	try {
-		IBattle& battle = m_serv.GetBattle(battleid);
-		if ((m_serv.GetMe().GetNick() == nick) || !useractions().DoActionOnUser(UserActions::ActIgnoreChat, TowxString(nick))) {
-			ui().OnSaidBattle(battle, TowxString(nick), TowxString(msg));
-		}
-		AutoHost* ah = battle.GetAutoHost();
-		if (ah != NULL) {
-			ah->OnSaidBattle(TowxString(nick), TowxString(msg));
-		}
-	} catch (assert_exception) {
-	}
-}
-
-void ServerEvents::OnBattleAction(int /*battleid*/, const std::string& nick, const std::string& msg)
-{
-	try {
-		UiEvents::GetUiEventSender(UiEvents::OnBattleActionEvent).SendEvent(
-		    UiEvents::OnBattleActionData(TowxString(nick), TowxString(msg)));
-	} catch (assert_exception) {
+	} catch (assert_exception&) {
 	}
 }
 
@@ -753,7 +808,7 @@ void ServerEvents::OnBattleStartRectAdd(int battleid, int allyno, int left, int
 		IBattle& battle = m_serv.GetBattle(battleid);
 		battle.AddStartRect(allyno, left, top, right, bottom);
 		battle.StartRectAdded(allyno);
-	} catch (assert_exception) {
+	} catch (assert_exception&) {
 	}
 }
 
@@ -764,7 +819,7 @@ void ServerEvents::OnBattleStartRectRemove(int battleid, int allyno)
 		IBattle& battle = m_serv.GetBattle(battleid);
 		battle.RemoveStartRect(allyno);
 		battle.StartRectRemoved(allyno);
-	} catch (assert_exception) {
+	} catch (assert_exception&) {
 	}
 }
 
@@ -777,7 +832,7 @@ void ServerEvents::OnBattleAddBot(int battleid, const std::string& nick, UserBat
 		battle.OnBotAdded(nick, status);
 		User& bot = battle.GetUser(nick);
 		ui().OnUserJoinedBattle(battle, bot);
-	} catch (assert_exception) {
+	} catch (assert_exception&) {
 	}
 }
 
@@ -834,10 +889,81 @@ void ServerEvents::OnServerMessageBox(const std::string& message)
 
 void ServerEvents::OnChannelMessage(const std::string& channel, const std::string& msg)
 {
-	ui().OnChannelMessage(m_serv.GetChannel(channel), msg);
+	try {
+		int battleid = m_serv.m_battles.BattleFromChannel(channel);
+		if (battleid != -1) {
+			IBattle& battle = m_serv.GetBattle(battleid);
+			ui().OnBattleMessage(battle, msg);
+			return; // FIXME: send topic to battle
+		}
+		ui().OnChannelMessage(m_serv.GetChannel(channel), msg);
+	} catch (std::runtime_error& except) {
+		wxLogWarning("Channel doesn't exist: '%s' msg: %s", channel.c_str(), msg.c_str());
+	}
 }
 
 
+void ServerEvents::OnJoinedFrom(const std::string& channel, const std::string& who)
+{
+	slLogDebugFunc("");
+	try {
+		int battleid = m_serv.m_battles.BattleFromChannel(channel);
+		if (battleid != -1) // don't display as a channel, if its a battle
+		{
+			User& user = m_serv.GetUser(who);
+			IBattle& battle = m_serv.GetBattle(battleid);
+			battle.OnUserAdded(user);
+			battle.ForceSpectator(user, true); // bridged users have no battle status
+			ui().OnUserJoinedBattle(battle, user);
+			return;
+		}
+		m_serv.GetChannel(channel).Joined(m_serv.GetUser(who));
+	} catch (std::runtime_error& except) {
+	}
+}
+
+void ServerEvents::OnLeftFrom(const std::string& channel, const std::string& who)
+{
+	slLogDebugFunc("");
+	try {
+		int battleid = m_serv.m_battles.BattleFromChannel(channel);
+		if (battleid != -1) {
+			IBattle& battle = m_serv.GetBattle(battleid);
+			User& user = battle.GetUser(who);
+			// this is necessary since the user will be deleted when the gui function is called
+			bool isbot = user.BattleStatus().IsBot();
+			user.BattleStatus().scriptPassword.clear();
+			battle.OnUserRemoved(user);
+			ui().OnUserLeftBattle(battle, user, isbot);
+		} else {
+			m_serv.GetChannel(channel).Left(m_serv.GetUser(who), "");
+		}
+
+		if (!m_serv.UserIsOnBridge(who)) {
+			User& user = m_serv.GetUser(who);
+			ui().OnUserOffline(user);
+			m_serv._RemoveUser(who);
+		}
+	} catch (std::runtime_error& except) {
+	}
+}
+
+void ServerEvents::OnSaidFrom(const std::string& channel, const std::string& who, const std::string& message)
+{
+	slLogDebugFunc("");
+	try {
+		if (not((m_serv.GetMe().GetNick() == who) || !useractions().DoActionOnUser(UserActions::ActIgnoreChat, TowxString(who))))
+			return;
+		int battleid = m_serv.m_battles.BattleFromChannel(channel);
+		if (battleid != -1) {
+			OnBattleSaid(battleid, who, message);
+			return;
+		}
+		m_serv.GetChannel(channel).Said(m_serv.GetUser(who), message);
+	} catch (std::runtime_error& except) {
+	}
+}
+
 void ServerEvents::OnHostExternalUdpPort(const unsigned int udpport)
 {
 	if (!m_serv.GetCurrentBattle())
@@ -877,18 +1003,16 @@ void ServerEvents::OnClientIPPort(const std::string& username, const std::string
 		wxLogMessage(_T("set to %s %d "), user.BattleStatus().ip.c_str(), user.BattleStatus().udpport);
 
 		if (sett().GetShowIPAddresses()) {
-			UiEvents::GetUiEventSender(UiEvents::OnBattleActionEvent).SendEvent(
-			    UiEvents::OnBattleActionData(TowxString(username), wxString::Format(_(" has ip=%s"), ip.c_str())));
+			UiEvents::GetUiEventSender(UiEvents::OnBattleActionEvent).SendEvent(UiEvents::OnBattleActionData(TowxString(username), wxString::Format(_(" has ip=%s"), ip.c_str())));
 		}
 
 		if (m_serv.GetCurrentBattle()->GetNatType() != NAT_None && (udpport == 0)) {
 			// todo: better warning message
 			//something.OutputLine( _T(" ** ") + who.GetNick() + _(" does not support nat traversal! ") + GetChatTypeStr() + _T("."), sett().GetChatColorJoinPart(), sett().GetChatFont() );
-			UiEvents::GetUiEventSender(UiEvents::OnBattleActionEvent).SendEvent(
-			    UiEvents::OnBattleActionData(TowxString(username), _(" does not really support nat traversal")));
+			UiEvents::GetUiEventSender(UiEvents::OnBattleActionEvent).SendEvent(UiEvents::OnBattleActionData(TowxString(username), _(" does not really support nat traversal")));
 		}
 		m_serv.GetCurrentBattle()->CheckBan(user);
-	} catch (std::runtime_error) {
+	} catch (std::runtime_error&) {
 		wxLogMessage(_T("runtime_error inside OnClientIPPort()"));
 	}
 }
@@ -984,8 +1108,7 @@ void ServerEvents::OnForceJoinBattle(int battleid, const std::string& scriptPW)
 		m_serv.LeaveBattle(battle->GetID());
 	}
 	m_serv.JoinBattle(battleid, scriptPW);
-	UiEvents::GetStatusEventSender(UiEvents::addStatusMessage).SendEvent(
-	    UiEvents::StatusData(_("Automatically moved to new battle"), 1));
+	UiEvents::GetStatusEventSender(UiEvents::addStatusMessage).SendEvent(UiEvents::StatusData(_("Automatically moved to new battle"), 1));
 }
 
 void ServerEvents::RegistrationAccepted(const std::string& user, const std::string& pass)
@@ -1007,5 +1130,3 @@ void ServerEvents::OnInvalidFingerprintReceived(const std::string& fingerprint,
 {
 	ui().OnInvalidFingerprintReceived(fingerprint, expected_fingerprint);
 }
-
-
