@@ -3,24 +3,21 @@
 /**
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
-DO NOT CHANGE THIS FILE!
-
-this file is deprecated and will be replaced with
+TODO: remove all wx stuff & merge / move to
 
 lsl/container/userlist.cpp
 
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 **/
+#include "userlist.h"
 
-
+#include <wx/log.h>
 #include <iterator>
 #include <stdexcept>
-#include <wx/log.h>
 
-#include "userlist.h"
+#include "log.h"
 #include "user.h"
 #include "utils/conversion.h"
-#include "log.h"
 
 const UserList::user_map_t::size_type SEEKPOS_INVALID = UserList::user_map_t::size_type(-1);
 
@@ -30,19 +27,11 @@ UserList::UserList()
 {
 }
 
-/*
-UserList& UserList::operator= (const UserList&& other)
+UserList::~UserList()
 {
-	// CAUTION: This list is being moved, but the m_users map contains pointers to objects.
-	//   If those objects are part of a subclass of the other object, then they are also about
-	//   to be deleted, so subclasses of UserList (OfflineBattle) need to take action in their
-	//   own move assignment function.
-	m_users = other.m_users;
 	m_seek = m_users.end();
 	m_seekpos = SEEKPOS_INVALID;
-	return *this;
 }
-*/
 
 void UserList::AddUser(User& user)
 {
