@@ -14,12 +14,14 @@
 
 #include <wx/string.h>
 #include <string>
-
-
 wxString TowxString(const std::string& arg);
 wxString TowxString(int);
 std::string strtolower(std::string str);
 
+#if defined(__WIN32__) || defined(_MSC_VER)
+std::string Utf8ToLocalEncoding(const char* str);
+#endif
+
 long FromwxString(const wxString& arg);
 
 /** @} */
